@@ -9,7 +9,7 @@
 
 from __future__ import with_statement
 
-__version__ = '0.5.12'
+__version__ = '0.5.15'
 
 # import sip
 # sip.setapi('QString', 2)
@@ -38,7 +38,7 @@ import re
 try:
     from QtMobility.Location import QGeoPositionInfoSource
 except:
-    print 'Pysode QtMobility not installed or broken'
+    print 'Pyside QtMobility not installed or broken'
     
 class KhweeteurDBusHandler(dbus.service.Object):
 
@@ -761,16 +761,24 @@ class KhweeteurWin(QMainWindow):
 
     @Slot()
     def do_tb_retweet(self):
+
         tweet_id = None
         for index in self.view.selectedIndexes():
             tweet_id = self.model.data(index, role=IDROLE)
             tweet_source = self.model.data(index, role=ORIGINROLE)
+            tweet_text = self.model.data(index, role=Qt.DisplayRole)
             if self.model.data(index, role=PROTECTEDROLE):
                 screenname = self.model.data(index, role=SCREENNAMEROLE)
                 QMessageBox.warning(self, 'Khweeteur - Retweet',
                                     "%s protect his tweets you can't retweet them"
                                      % screenname, QMessageBox.Close)
 
+        if not (( QMessageBox.question(None,
+            "Kheeteur Retweet",
+            "Did you want to retweet '%s'?" % tweet_text,
+            QMessageBox.Yes| QMessageBox.Close)) ==  QMessageBox.Yes):
+            tweet_id = None
+
         if tweet_id:
             self.dbus_handler.post_tweet(  # shorten_url=\
                                            # serialize=\
@@ -797,6 +805,13 @@ class KhweeteurWin(QMainWindow):
         for index in self.view.selectedIndexes():
             tweet_id = self.model.data(index, role=IDROLE)
             tweet_source = self.model.data(index, role=ORIGINROLE)
+            tweet_text = self.model.data(index, role=Qt.DisplayRole)
+
+        if not (( QMessageBox.question(None,
+            "Kheeteur Delete",
+            "Did you really want to delete '%s'?" % tweet_text,
+            QMessageBox.Yes| QMessageBox.Close)) ==  QMessageBox.Yes):
+            tweet_id = None
 
         if tweet_id:
             self.dbus_handler.post_tweet(  # shorten_url=\
@@ -824,6 +839,13 @@ class KhweeteurWin(QMainWindow):
         for index in self.view.selectedIndexes():
             tweet_id = self.model.data(index, role=IDROLE)
             tweet_source = self.model.data(index, role=ORIGINROLE)
+            tweet_text = self.model.data(index, role=Qt.DisplayRole)
+
+        if not (( QMessageBox.question(None,
+            "Kheeteur Favorite",
+            "Did you really want to favorite '%s'?" % tweet_text,
+            QMessageBox.Yes| QMessageBox.Close)) ==  QMessageBox.Yes):
+            tweet_id = None
 
         if tweet_id:
             self.dbus_handler.post_tweet(  # shorten_url=\
@@ -851,6 +873,13 @@ class KhweeteurWin(QMainWindow):
         for index in self.view.selectedIndexes():
             user_id = self.model.data(index, role=USERIDROLE)
             tweet_source = self.model.data(index, role=ORIGINROLE)
+            screenname = self.model.data(index, role=SCREENNAMEROLE)
+
+        if not (( QMessageBox.question(None,
+            "Kheeteur Follow",
+            "Did you really want to follow '%s'?" % screenname,
+            QMessageBox.Yes| QMessageBox.Close)) ==  QMessageBox.Yes):
+            user_id = None
 
         if user_id:
             self.dbus_handler.post_tweet(  # shorten_url=\
@@ -878,6 +907,13 @@ class KhweeteurWin(QMainWindow):
         for index in self.view.selectedIndexes():
             user_id = self.model.data(index, role=USERIDROLE)
             tweet_source = self.model.data(index, role=ORIGINROLE)
+            screenname = self.model.data(index, role=SCREENNAMEROLE)
+
+        if not (( QMessageBox.question(None,
+            "Kheeteur Unfollow",
+            "Did you really want to unfollow '%s'?" % screenname,
+            QMessageBox.Yes| QMessageBox.Close)) ==  QMessageBox.Yes):
+            user_id = None
 
         if user_id:
             self.dbus_handler.post_tweet(  # shorten_url=\
@@ -1068,7 +1104,7 @@ class KhweeteurWin(QMainWindow):
         settings = QSettings()
         self.geoloc_source = None
         if settings.contains('useGPS'):
-            if settings.value('useGPS') == '2':
+            if (settings.value('useGPS') == '2') and (settings.value('useGPSOnDemand')!='2'):
                 self.geolocStart()
             else:
                 self.geolocStop()
